@@ -306,14 +306,14 @@ def num_gigs(request):
 def load_data(connector, batch, good_object_id, mapping_object, _replace, num_gigs, batch_size, batch_rows):
     print(f"\nNow loading {num_gigs} GB!")
     size = num_gigs
+    object_id = "load_" + str(num_gigs) + "GB_" + good_object_id
     batch_number = 1
     rows_loaded = 0
-    generate_data_time = 0
     elapsed_time = 0
     total_batches = math.ceil((size * GB) / float(sys.getsizeof(batch)))
 
     start = time.time()
-    connector.load_data(batch, good_object_id, mapping_object, _replace, batch_number, total_batches)
+    connector.load_data(batch, object_id, mapping_object, _replace, batch_number, total_batches)
     end = time.time()
     elapsed_time += (end - start)
 
@@ -324,7 +324,7 @@ def load_data(connector, batch, good_object_id, mapping_object, _replace, num_gi
         batch_number += 1
 
         start = time.time()
-        connector.load_data(batch, good_object_id, mapping_object, _replace, batch_number, total_batches)
+        connector.load_data(batch, object_id, mapping_object, _replace, batch_number, total_batches)
         end = time.time()
         elapsed_time += (end - start)
 
